==> apache_superset-4.1.3-source.tar.gz: apache_superset-4.1.3rc2/superset-frontend/src/SqlLab/components/ExploreResultsButton/ExploreResultsButton.test.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { render, screen } from 'spec/helpers/testing-library';

import ExploreResultsButton, {
  ExploreResultsButtonProps,
} from 'src/SqlLab/components/ExploreResultsButton';
import { OnClickHandler } from 'src/components/Button';

const setup = (
  onClickFn: OnClickHandler,
  props: Partial<ExploreResultsButtonProps> = {},
) =>
  render(<ExploreResultsButton onClick={onClickFn} {...props} />, {
    useRedux: true,
  });

describe('ExploreResultsButton', () => {
  it('renders', async () => {
    const { queryByText } = setup(jest.fn(), {
      database: { allows_subquery: true },
    });

    expect(queryByText('Create Chart')).toBeTruthy();
    expect(screen.getByRole('button', { name: 'Create Chart' })).toBeEnabled();
  });

  it('renders disabled if subquery not allowed', async () => {
    const { queryByText } = setup(jest.fn());

    expect(queryByText('Create Chart')).toBeTruthy();
    expect(screen.getByRole('button', { name: 'Create Chart' })).toBeDisabled();
  });
});

==> apache_superset-6.0.0-source.tar.gz: apache_superset-6.0.0rc4/superset-frontend/src/SqlLab/components/ExploreResultsButton/ExploreResultsButton.test.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { render, screen } from 'spec/helpers/testing-library';

import ExploreResultsButton, {
  ExploreResultsButtonProps,
} from 'src/SqlLab/components/ExploreResultsButton';
import type { OnClickHandler } from '@superset-ui/core/components';

const setup = (
  onClickFn: OnClickHandler,
  props: Partial<ExploreResultsButtonProps> = {},
) =>
  render(<ExploreResultsButton onClick={onClickFn} {...props} />, {
    useRedux: true,
  });

describe('ExploreResultsButton', () => {
  it('renders', async () => {
    const { queryByText } = setup(jest.fn(), {
      database: { allows_subquery: true },
    });
    expect(queryByText('Create chart')).toBeInTheDocument();
    // Updated line to match the actual button name that includes the icon
    expect(screen.getByRole('button', { name: /Create chart/i })).toBeEnabled();
  });

  it('renders disabled if subquery not allowed', async () => {
    const { queryByText } = setup(jest.fn());
    expect(queryByText('Create chart')).toBeInTheDocument();
    // Updated line to match the actual button name that includes the icon
    expect(
      screen.getByRole('button', { name: /Create chart/i }),
    ).toBeDisabled();
  });
});
